===========
Django Suit
===========

**Modern theme for Django admin interface**.

Django Suit is alternative theme/skin/extension for `Django <http://www.djangoproject.com>`_ administration interface.

Project home: http://djangosuit.com/


License
=======

Django Suit is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.

Licence and pricing: http://djangosuit.com/pricing/


Support
=======

Support and documentation: http://djangosuit.com/support/

`Demo app <http://djangosuit.com/admin/>`_ repository is here: `django-suit-examples <https://github.com/darklow/django-suit-examples>`_


Changelog
=========

See `CHANGELOG.rst <https://github.com/darklow/django-suit/blob/master/CHANGELOG.rst>`_.
